==> nodejs_interop-0.7.0.tar.gz: lib/src/io/process/process_manager.dart <==
part of nodejs_interop.io;

/// Manages the creation of processes.
class ProcessManager implements process_manager.ProcessManager {

  /// Creates a new process manager.
  const ProcessManager();

  /// TODO
  @override
  bool canRun(executable, {String workingDirectory}) => throw new UnimplementedError();

  /// Kills the process with identifier [pid]. Where possible, sends the [signal] to the process.
  ///
  /// Returns `true` if the [signal] is successfully delivered to the process with identifier [pid].
  /// Otherwise the signal could not be sent, usually meaning that the process is already dead.
  @override
  bool killPid(int pid, [io.ProcessSignal signal = io.ProcessSignal.SIGTERM]) => Process.killPid(pid, signal);

  /// Starts a process and runs it non-interactively to completion.
  ///
  /// Returns a [Future] that completes with the [ProcessResult] of running the process, i.e. exit code, standard out and standard in.
  @override
  Future<io.ProcessResult> run(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    bool runInShell = false,
    Encoding stderrEncoding = UTF8,
    Encoding stdoutEncoding = UTF8,
    String workingDirectory
  }) => Process.run(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    stderrEncoding: stderrEncoding,
    stdoutEncoding: stdoutEncoding,
    workingDirectory: workingDirectory
  );

  /// Starts a process and runs it to completion.
  /// This is a synchronous call and will block until the child process terminates.
  ///
  /// Returns a [ProcessResult] with the result of running the process, i.e. exit code, standard out and standard in.
  @override
  io.ProcessResult runSync(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    bool runInShell = false,
    Encoding stderrEncoding = UTF8,
    Encoding stdoutEncoding = UTF8,
    String workingDirectory
  }) => Process.runSync(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    stderrEncoding: stderrEncoding,
    stdoutEncoding: stdoutEncoding,
    workingDirectory: workingDirectory
  );

  /// Starts a process. Returns a [Future] that completes with a [Process] instance when the process has been successfully started.
  /// That object can be used to interact with the process. If the process cannot be started the returned future completes with an exception.
  @override
  Future<Process> start(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    io.ProcessStartMode mode = io.ProcessStartMode.NORMAL,
    bool runInShell = false,
    String workingDirectory
  }) => Process.start(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    workingDirectory: workingDirectory
  );
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/io/process/process_manager.dart <==
part of nodejs_interop.io;

/// Manages the creation of processes.
class ProcessManager implements process_manager.ProcessManager {

  /// Creates a new process manager.
  const ProcessManager();

  /// TODO
  @override
  bool canRun(executable, {String workingDirectory}) => throw new UnimplementedError('ProcessManager.canRun');

  /// Kills the process with identifier [pid]. Where possible, sends the [signal] to the process.
  ///
  /// Returns `true` if the [signal] is successfully delivered to the process with identifier [pid].
  /// Otherwise the signal could not be sent, usually meaning that the process is already dead.
  @override
  bool killPid(int pid, [io.ProcessSignal signal = io.ProcessSignal.SIGTERM]) => Process.killPid(pid, signal);

  /// Starts a process and runs it non-interactively to completion.
  ///
  /// Returns a [Future] that completes with the [ProcessResult] of running the process, i.e. exit code, standard out and standard in.
  @override
  Future<io.ProcessResult> run(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    bool runInShell = false,
    Encoding stderrEncoding = UTF8,
    Encoding stdoutEncoding = UTF8,
    String workingDirectory
  }) => Process.run(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    stderrEncoding: stderrEncoding,
    stdoutEncoding: stdoutEncoding,
    workingDirectory: workingDirectory
  );

  /// Starts a process and runs it to completion.
  /// This is a synchronous call and will block until the child process terminates.
  ///
  /// Returns a [ProcessResult] with the result of running the process, i.e. exit code, standard out and standard in.
  @override
  io.ProcessResult runSync(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    bool runInShell = false,
    Encoding stderrEncoding = UTF8,
    Encoding stdoutEncoding = UTF8,
    String workingDirectory
  }) => Process.runSync(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    stderrEncoding: stderrEncoding,
    stdoutEncoding: stdoutEncoding,
    workingDirectory: workingDirectory
  );

  /// Starts a process. Returns a [Future] that completes with a [Process] instance when the process has been successfully started.
  /// That object can be used to interact with the process. If the process cannot be started the returned future completes with an exception.
  @override
  Future<Process> start(List command, {
    Map<String, String> environment,
    bool includeParentEnvironment = true,
    io.ProcessStartMode mode = io.ProcessStartMode.NORMAL,
    bool runInShell = false,
    String workingDirectory
  }) => Process.start(
    command.first.toString(),
    command.skip(1).map((arg) => arg.toString()).toList(),
    environment: environment,
    includeParentEnvironment: includeParentEnvironment,
    runInShell: runInShell,
    workingDirectory: workingDirectory
  );
}
